pub struct RingBuffer<T>where
T: Clone,{ /* private fields */ }Expand description
Fixed-size ring buffer with metrics
Implementations
Sourceimpl<T> RingBuffer<T>where
T: Clone,
impl<T> RingBuffer<T>where
T: Clone,
Sourcepub fn new(capacity: usize) -> RingBuffer<T>
pub fn new(capacity: usize) -> RingBuffer<T>
Create a new ring buffer with given capacity
Sourcepub fn push(&mut self, item: T) -> bool
pub fn push(&mut self, item: T) -> bool
Push an item into the buffer Returns true if item was added, false if buffer was full and old item was dropped
Sourcepub fn metrics(&self) -> Arc<RingBufferMetrics>
pub fn metrics(&self) -> Arc<RingBufferMetrics>
Get metrics reference